aboutsummaryrefslogtreecommitdiffstats
path: root/examples/network/fortuneclient.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/network/fortuneclient.py')
-rw-r--r--examples/network/fortuneclient.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/network/fortuneclient.py b/examples/network/fortuneclient.py
index ee4bc5670..99ca41b0e 100644
--- a/examples/network/fortuneclient.py
+++ b/examples/network/fortuneclient.py
@@ -40,9 +40,9 @@
##
#############################################################################
-"""PySide2 port of the network/fortuneclient example from Qt v5.x"""
+"""PySide6 port of the network/fortuneclient example from Qt v5.x"""
-from PySide2 import QtCore, QtGui, QtWidgets, QtNetwork
+from PySide6 import QtCore, QtGui, QtWidgets, QtNetwork
class Client(QtWidgets.QDialog):